(*
 JungTaek Kim, The LET Project, KAIST

 Copyright(c) 2000 Research On Program Analysis System
 National Creative Research Initiative Center
 Korea Advanced Institute of Science & Technology
 http://ropas.kaist.ac.kr

 All rights reserved. This file is distributed under the terms of
 an Open Source License.
*)

open Location
open Format

let parse_file filename =
  let ic = open_in_bin filename in
  let ast =
    try
      Location.input_name := filename;
      Parse.batch_parse (Lexing.from_channel ic)
    with x -> close_in ic; raise x;
  in
    String_ast.Ast.print_topdec ast;
    close_in ic

let optionlist =
  [
   ("-hangul", Arg.Unit 
   (fun () -> 
     (match !(Syntaxerr.errmsg_type) with
       Syntaxerr.EngGentle -> Syntaxerr.errmsg_type := Syntaxerr.HanGentle
     | _ -> ())),
   "Turn on Hangul syntax error messages.");
   ("-tough", Arg.Unit (fun () -> 
     (match !(Syntaxerr.errmsg_type) with
       Syntaxerr.HanGentle -> Syntaxerr.errmsg_type := Syntaxerr.HanTough
     | _ -> ())),
   "Turn on Tough syntax error messages.");
   ("-", Arg.String parse_file,
    "<file>  Treat <file> as a file name (even if it starts with `-')")
   ]

let usage = "Usage: nmlc <files>\nOptions are:"

let main () =
  Format.set_formatter_out_channel stderr;
  try
    Arg.parse optionlist parse_file usage;
    printf "@.";
    exit 0
  with x ->
    printf "@.";
    (match x with
      Lexer.Error(err, start, stop) ->
        Location.print {loc_start = start; loc_end = stop; loc_ghost = false};
        Lexer.report_error err
    | Syntaxerr.Error err ->
        Syntaxerr.report_error err
    | x -> raise x);
    printf "\n";
    exit 2

let _ = Printexc.catch main ()

